package Bundle::MyLibrary;

$VERSION = '0.02';

1;

__END__

=head1 NAME 

Bundle::MyLibrary - MyLibrary Module Dependencies

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::MyLibrary>

=head1 DESCRIPTION

These are Perl dependencies for the MyLibrary portal software.
L<http://dewey.library.nd.edu/mylibrary/>

=head1 CONTENTS

CGI
DBI
DBD::mysql
Pod::Parser
Data::ShowTable
URI
HTML::Parser
Bundle::libnet
Bundle::LWP
Digest
Digest::MD5
MIME::Base64
MIME::Decoder::Base64
Mail::Send
IO::Stringy
MIME-tools
Mail::Send
Time::CTime
Time::ParseDate

=head1 AUTHOR

Ed Summers e<lt>ehs@pobox.come<gt>

